@@ -86,15 +86,23 @@ class Field(object):
         self.default = default
         self.required = bool(required) if self.default is None else False
         # Added validator for check on required field.
+        self._src_validators = validators
         self._validators = ([RequiredValidator()] if self.required else []) + (validators or [])[:]
 
         # Make errors dict.
         messages = {}
+        self._src_messages = messages
         for cls in reversed(self.__class__.__mro__):
             messages.update(getattr(cls, 'default_error_messages', {}))
         messages.update(error_messages or {})
         self.error_messages = messages
 
+    def __deepcopy__(self, memo={}):
+        return self.__class__(
+            required=self.required, default=self.default, label=self.label,
+            validators=self._src_validators, error_messages=self._src_messages
+        )
+
     def bind(self, field_name, parent):
         """
         Initialization field name and parent instance .
@@ -378,6 +386,14 @@ class CharField(Field):
             message = self.error_messages['min_length'].format(min_length=self.min_length)
             self.validators.append(MinLengthValidator(self.min_length, message=message))
 
+    def __deepcopy__(self, memo={}):
+        return self.__class__(
+            required=self.required, default=self.default, label=self.label,
+            validators=self._src_validators, error_messages=self._src_messages,
+            min_length=self.min_length, max_length=self.max_length,
+            trim_whitespace=self.trim_whitespace, allow_blank=self.allow_blank
+        )
+
     def run_validation(self, data=None):
         """
         We check for an empty string here, so that it does not fall into subclasses in `.to_internal_value ()`.
@@ -409,7 +425,13 @@ class CharField(Field):
         # We skip numbers as strings, but bool as strings seems to be a developer error.
         if isinstance(data, bool) or not isinstance(data, six.string_types + six.integer_types + (float,)):
             self.fail('invalid')
-        return six.text_type(data)
+
+        val = six.text_type(data)
+
+        if self.trim_whitespace:
+            val = val.strip()
+
+        return val
 
     def to_representation(self, value):
         """
@@ -458,6 +480,13 @@ class IntegerField(Field):
             message = self.error_messages['max_value'].format(max_value=self.max_value)
             self.validators.append(MaxValueValidator(self.max_value, message=message))
 
+    def __deepcopy__(self, memo={}):
+        return self.__class__(
+            required=self.required, default=self.default, label=self.label,
+            validators=self._src_validators, error_messages=self._src_messages,
+            min_value=self.min_value, max_value=self.max_value
+        )
+
     def to_internal_value(self, data):
         """
         Data transformation to python object.
@@ -526,6 +555,13 @@ class FloatField(Field):
             message = self.error_messages['max_value'].format(max_value=self.max_value)
             self.validators.append(MaxValueValidator(self.max_value, message=message))
 
+    def __deepcopy__(self, memo={}):
+        return self.__class__(
+            required=self.required, default=self.default, label=self.label,
+            validators=self._src_validators, error_messages=self._src_messages,
+            min_value=self.min_value, max_value=self.max_value
+        )
+
     def to_internal_value(self, data):
         """
         Data transformation to python object.
@@ -564,6 +600,71 @@ class BooleanField(Field):
     """
     Field for boolean type.
 
+    """
+    default_error_messages = {
+        'invalid': '"{input}" must be a valid boolean type.'
+    }
+    TRUE_VALUES = {
+        't', 'T',
+        'y', 'Y', 'yes', 'YES', 'Yes',
+        'true', 'True', 'TRUE',
+        'on', 'On', 'ON',
+        '1', 1,
+        True
+    }  # Dict with True options.
+    FALSE_VALUES = {
+        'f', 'F', 'n',
+        'N', 'no', 'NO', 'No',
+        'false', 'False', 'FALSE',
+        'off', 'Off', 'OFF',
+        '0', 0, 0.0,
+        False
+    }  # Dictionary with False options.
+
+    def to_internal_value(self, data):
+        """
+        Data transformation to python object.
+
+        :param Union[str, int, float, bool] data: Data for transformation.
+
+        :return: Transformed data.
+        :rtype: bool
+
+        :raise ValidationError: If not valid data.
+
+        """
+        try:
+            if data in self.TRUE_VALUES:
+                return True
+            elif data in self.FALSE_VALUES:
+                return False
+        except TypeError:  # If the non-hash type came.
+            pass
+        self.fail('invalid', input=data)
+
+    def to_representation(self, value):
+        """
+        Transformation an object to a valid JSON object.
+
+        :param Union[str, int, float, bool] value: The object to transformation.
+
+        :return: Transformed data.
+        :rtype: bool
+
+        """
+        # First we look for in the match table.
+        if value in self.TRUE_VALUES:
+            return True
+        elif value in self.FALSE_VALUES:
+            return False
+        # If not found, try to transform.
+        return bool(value)
+
+
+class BooleanNullField(Field):
+    """
+    Field for boolean type.
+
     """
     default_error_messages = {
         'invalid': '"{input}" must be a valid boolean type.'
@@ -713,6 +814,14 @@ class ListField(Field):
             message = self.error_messages['min_length'].format(min_length=self.min_length)
             self.validators.append(MinLengthValidator(self.min_length, message=message))
 
+    def __deepcopy__(self, memo={}):
+        return self.__class__(
+            required=self.required, default=self.default, label=self.label,
+            validators=self._src_validators, error_messages=self._src_messages,
+            child=self.child, min_length=self.min_length, max_length=self.max_length,
+            allow_empty=self.allow_empty
+        )
+
     def to_internal_value(self, data):
         """
         Data transformation to python list object.
@@ -776,6 +885,13 @@ class DateField(Field):
             self.input_format = input_format
         super().__init__(*args, **kwargs)
 
+    def __deepcopy__(self, memo={}):
+        return self.__class__(
+            required=self.required, default=self.default, label=self.label,
+            validators=self._src_validators, error_messages=self._src_messages,
+            format=getattr(self, 'format'), input_format=getattr(self, 'input_format')
+        )
+
     def to_internal_value(self, data):
         """
         Data transformation to python datetime object.
@@ -868,6 +984,13 @@ class TimeField(Field):
             self.input_format = input_format
         super().__init__(*args, **kwargs)
 
+    def __deepcopy__(self, memo={}):
+        return self.__class__(
+            required=self.required, default=self.default, label=self.label,
+            validators=self._src_validators, error_messages=self._src_messages,
+            format=getattr(self, 'format', None), input_format=getattr(self, 'input_format')
+        )
+
     def to_internal_value(self, data):
         """
         Data transformation to python datetime object.
@@ -958,6 +1081,13 @@ class DateTimeField(Field):
 
         super(DateTimeField, self).__init__(*args, **kwargs)
 
+    def __deepcopy__(self, memo={}):
+        return self.__class__(
+            required=self.required, default=self.default, label=self.label,
+            validators=self._src_validators, error_messages=self._src_messages,
+            format=getattr(self, 'format'), input_format=getattr(self, 'input_format')
+        )
+
     def to_internal_value(self, data):
         """
         Data transformation to python datetime object.
@@ -1083,6 +1213,13 @@ class DictField(JsonField):
 
         self.child.bind(field_name='', parent=self)  # Bind child field.
 
+    def __deepcopy__(self, memo={}):
+        return self.__class__(
+            required=self.required, default=self.default, label=self.label,
+            validators=self._src_validators, error_messages=self._src_messages,
+            child=self.child
+        )
+
     def to_internal_value(self, data):
         """
         Data transformation to python JSON object.
@@ -1161,6 +1298,13 @@ class SerializerMethodField(Field):
         self.method_name_get = method_name_get
         self.method_name_pop = method_name_pop
 
+    def __deepcopy__(self, memo={}):
+        return self.__class__(
+            required=self.required, default=self.default, label=self.label,
+            validators=self._src_validators, error_messages=self._src_messages,
+            method_name_get=self.method_name_get, method_name_pop=self.method_name_pop
+        )
+
     def bind(self, field_name, parent):
         """
         Initialization field name and parent instance .
